@@ -31,6 +31,213 @@ struct focus_change_data_struct {
 
 static GSList *focus_data_list = NULL;
 
+static void
+draw_hline (GtkStyle *style,
+	    GdkWindow *window,
+	    GtkStateType state_type,
+	    GdkRectangle *area,
+	    GtkWidget *widget,
+	    const gchar *detail,
+	    gint x1, gint x2, gint y);
+
+static void
+draw_vline (GtkStyle *style,
+	    GdkWindow *window,
+	    GtkStateType state_type,
+	    GdkRectangle *area,
+	    GtkWidget *widget, const gchar *detail, gint y1, gint y2, gint x);
+
+static void
+draw_shadow (GtkStyle *style,
+	     GdkWindow *window,
+	     GtkStateType state_type,
+	     GtkShadowType shadow_type,
+	     GdkRectangle *area,
+	     GtkWidget *widget,
+	     const gchar *detail, gint x, gint y, gint width, gint height);
+
+static void
+draw_box (GtkStyle *style,
+	  GdkWindow *window,
+	  GtkStateType state_type,
+	  GtkShadowType shadow_type,
+	  GdkRectangle *area,
+	  GtkWidget *widget,
+	  const gchar *detail, gint x, gint y, gint width, gint height);
+
+static void
+draw_polygon (GtkStyle *style,
+	      GdkWindow *window,
+	      GtkStateType state_type,
+	      GtkShadowType shadow_type,
+	      GdkRectangle *area,
+	      GtkWidget *widget,
+	      const gchar *detail, GdkPoint *points, gint npoints, gint fill);
+
+static void
+draw_arrow (GtkStyle *style,
+	    GdkWindow *window,
+	    GtkStateType state_type,
+	    GtkShadowType shadow_type,
+	    GdkRectangle *area,
+	    GtkWidget *widget,
+	    const gchar *detail,
+	    GtkArrowType arrow_type,
+	    gint fill, gint x, gint y, gint width, gint height);
+
+static void
+draw_diamond (GtkStyle *style,
+	      GdkWindow *window,
+	      GtkStateType state_type,
+	      GtkShadowType shadow_type,
+	      GdkRectangle *area,
+	      GtkWidget *widget,
+	      const gchar *detail, gint x, gint y, gint width, gint height);
+
+static void
+draw_oval (GtkStyle *style,
+	   GdkWindow *window,
+	   GtkStateType state_type,
+	   GtkShadowType shadow_type,
+	   GdkRectangle *area,
+	   GtkWidget *widget,
+	   const gchar *detail, gint x, gint y, gint width, gint height);
+
+static void
+draw_string (GtkStyle *style,
+	     GdkWindow *window,
+	     GtkStateType state_type,
+	     GdkRectangle *area,
+	     GtkWidget *widget,
+	     const gchar *detail, gint x, gint y, const gchar *string);
+static void
+draw_flat_box (GtkStyle *style,
+	       GdkWindow *window,
+	       GtkStateType state_type,
+	       GtkShadowType shadow_type,
+	       GdkRectangle *area,
+	       GtkWidget *widget,
+	       const gchar *detail, gint x, gint y, gint width, gint height);
+
+static void
+draw_check (GtkStyle *style,
+	    GdkWindow *window,
+	    GtkStateType state_type,
+	    GtkShadowType shadow_type,
+	    GdkRectangle *area,
+	    GtkWidget *widget,
+	    const gchar *detail, gint x, gint y, gint width, gint height);
+static void
+draw_option (GtkStyle *style,
+	     GdkWindow *window,
+	     GtkStateType state_type,
+	     GtkShadowType shadow_type,
+	     GdkRectangle *area,
+	     GtkWidget *widget,
+	     const gchar *detail, gint x, gint y, gint width, gint height);
+
+static void
+draw_cross (GtkStyle *style,
+	    GdkWindow *window,
+	    GtkStateType state_type,
+	    GtkShadowType shadow_type,
+	    GdkRectangle *area,
+	    GtkWidget *widget,
+	    const gchar *detail, gint x, gint y, gint width, gint height);
+
+static void
+draw_ramp (GtkStyle *style,
+	   GdkWindow *window,
+	   GtkStateType state_type,
+	   GtkShadowType shadow_type,
+	   GdkRectangle *area,
+	   GtkWidget *widget,
+	   const gchar *detail,
+	   GtkArrowType arrow_type, gint x, gint y, gint width, gint height);
+
+static void
+draw_tab (GtkStyle *style,
+	  GdkWindow *window,
+	  GtkStateType state_type,
+	  GtkShadowType shadow_type,
+	  GdkRectangle *area,
+	  GtkWidget *widget,
+	  const gchar *detail, gint x, gint y, gint width, gint height);
+
+static void
+draw_shadow_gap (GtkStyle *style,
+		 GdkWindow *window,
+		 GtkStateType state_type,
+		 GtkShadowType shadow_type,
+		 GdkRectangle *area,
+		 GtkWidget *widget,
+		 const gchar *detail,
+		 gint x,
+		 gint y,
+		 gint width,
+		 gint height,
+		 GtkPositionType gap_side, gint gap_x, gint gap_width);
+
+static void
+draw_box_gap (GtkStyle *style,
+	      GdkWindow *window,
+	      GtkStateType state_type,
+	      GtkShadowType shadow_type,
+	      GdkRectangle *area,
+	      GtkWidget *widget,
+	      const gchar *detail,
+	      gint x,
+	      gint y,
+	      gint width,
+	      gint height,
+	      GtkPositionType gap_side, gint gap_x, gint gap_width);
+
+static void
+draw_extension (GtkStyle *style,
+		GdkWindow *window,
+		GtkStateType state_type,
+		GtkShadowType shadow_type,
+		GdkRectangle *area,
+		GtkWidget *widget,
+		const gchar *detail,
+		gint x,
+		gint y, gint width, gint height, GtkPositionType gap_side);
+
+static void
+draw_focus (GtkStyle *style,
+	    GdkWindow *window,
+	    GtkStateType state_type,
+	    GdkRectangle *area,
+	    GtkWidget *widget,
+	    const gchar *detail, 
+	    gint x, 
+	    gint y, 
+	    gint width, 
+	    gint height);
+
+static void
+draw_slider (GtkStyle *style,
+	     GdkWindow *window,
+	     GtkStateType state_type,
+	     GtkShadowType shadow_type,
+	     GdkRectangle *area,
+	     GtkWidget *widget,
+	     const gchar *detail,
+	     gint x,
+	     gint y, gint width, gint height, GtkOrientation orientation);
+
+static void
+draw_handle (GtkStyle *style,
+	     GdkWindow *window,
+	     GtkStateType state_type,
+	     GtkShadowType shadow_type,
+	     GdkRectangle *area,
+	     GtkWidget *widget,
+	     const gchar *detail,
+	     gint x,
+	     gint y, gint width, gint height, GtkOrientation orientation);
+
+
 static focus_change_data *
 get_focus_data (GtkWidget *widget, gboolean add)
 {
@@ -691,7 +898,7 @@ paint_bullet (GdkWindow *window, GdkGC *gc, int x, int y)
 
 /* style functions */
 
-void
+static void
 draw_hline (GtkStyle *style,
 	    GdkWindow *window,
 	    GtkStateType state_type,
@@ -741,7 +948,7 @@ draw_hline (GtkStyle *style,
     }
 }
 
-void
+static void
 draw_vline (GtkStyle *style,
 	    GdkWindow *window,
 	    GtkStateType state_type,
@@ -789,7 +996,7 @@ draw_vline (GtkStyle *style,
     }
 }
 
-void
+static void
 draw_shadow (GtkStyle *style,
 	     GdkWindow *window,
 	     GtkStateType state_type,
@@ -1003,7 +1210,7 @@ draw_shadow (GtkStyle *style,
     }
 }
 
-void
+static void
 draw_box (GtkStyle *style,
 	  GdkWindow *window,
 	  GtkStateType state_type,
@@ -1288,7 +1495,7 @@ draw_box (GtkStyle *style,
     }
 }
 
-void
+static void
 draw_polygon (GtkStyle *style,
 	      GdkWindow *window,
 	      GtkStateType state_type,
@@ -1434,7 +1641,7 @@ draw_polygon (GtkStyle *style,
     }
 }
 
-void
+static void
 draw_arrow (GtkStyle *style,
 	    GdkWindow *window,
 	    GtkStateType state_type,
@@ -1571,7 +1778,7 @@ draw_arrow (GtkStyle *style,
     }
 }
 
-void
+static void
 draw_diamond (GtkStyle *style,
 	      GdkWindow *window,
 	      GtkStateType state_type,
@@ -1690,7 +1897,7 @@ draw_diamond (GtkStyle *style,
     }
 }
 
-void
+static void
 draw_oval (GtkStyle *style,
 	   GdkWindow *window,
 	   GtkStateType state_type,
@@ -1703,7 +1910,7 @@ draw_oval (GtkStyle *style,
     g_return_if_fail (window != NULL);
 }
 
-void
+static void
 draw_string (GtkStyle *style,
 	     GdkWindow *window,
 	     GtkStateType state_type,
@@ -1737,7 +1944,7 @@ draw_string (GtkStyle *style,
     }
 }
 
-void
+static void
 draw_flat_box (GtkStyle *style,
 	       GdkWindow *window,
 	       GtkStateType state_type,
@@ -1893,7 +2100,7 @@ paint_check (GtkStyle *style,
     }
 }
 
-void
+static void
 draw_check (GtkStyle *style,
 	    GdkWindow *window,
 	    GtkStateType state_type,
@@ -1906,7 +2113,7 @@ draw_check (GtkStyle *style,
 		 widget, detail, x, y, width, height, EAZEL_ENGINE_CHECK);
 }
 
-void
+static void
 draw_option (GtkStyle *style,
 	     GdkWindow *window,
 	     GtkStateType state_type,
@@ -1919,7 +2126,7 @@ draw_option (GtkStyle *style,
 		 widget, detail, x, y, width, height, EAZEL_ENGINE_OPTION);
 }
 
-void
+static void
 draw_cross (GtkStyle *style,
 	    GdkWindow *window,
 	    GtkStateType state_type,
@@ -1932,7 +2139,7 @@ draw_cross (GtkStyle *style,
     g_return_if_fail (window != NULL);
 }
 
-void
+static void
 draw_ramp (GtkStyle *style,
 	   GdkWindow *window,
 	   GtkStateType state_type,
@@ -1946,7 +2153,7 @@ draw_ramp (GtkStyle *style,
     g_return_if_fail (window != NULL);
 }
 
-void
+static void
 draw_tab (GtkStyle *style,
 	  GdkWindow *window,
 	  GtkStateType state_type,
@@ -1962,7 +2169,7 @@ draw_tab (GtkStyle *style,
 		   detail, x, y, width, height);
 }
 
-void
+static void
 draw_shadow_gap (GtkStyle *style,
 		 GdkWindow *window,
 		 GtkStateType state_type,
@@ -2019,7 +2226,7 @@ draw_shadow_gap (GtkStyle *style,
 				    rect.x, rect.y, rect.width, rect.height);
 }
 
-void
+static void
 draw_box_gap (GtkStyle *style,
 	      GdkWindow *window,
 	      GtkStateType state_type,
@@ -2084,7 +2291,7 @@ draw_box_gap (GtkStyle *style,
 				    rect.x, rect.y, rect.width, rect.height);
 }
 
-void
+static void
 draw_extension (GtkStyle *style,
 		GdkWindow *window,
 		GtkStateType state_type,
@@ -2176,7 +2383,7 @@ draw_extension (GtkStyle *style,
 				    rect.x, rect.y, rect.width, rect.height);
 }
 
-void
+static void
 draw_focus (GtkStyle *style,
 	    GdkWindow *window,
 	    GtkStateType state_type,
@@ -2240,7 +2447,7 @@ draw_focus (GtkStyle *style,
 	gdk_gc_set_clip_rectangle (style->black_gc, NULL);
 }
 
-void
+static void
 draw_slider (GtkStyle *style,
 	     GdkWindow *window,
 	     GtkStateType state_type,
@@ -2346,7 +2553,7 @@ draw_slider (GtkStyle *style,
 
 }
 
-void
+static void
 draw_handle (GtkStyle *style,
 	     GdkWindow *window,
 	     GtkStateType state_type,
@@ -2428,3 +2635,26 @@ draw_handle (GtkStyle *style,
     gdk_gc_set_clip_rectangle (light_gc, NULL);
     gdk_gc_set_clip_rectangle (dark_gc, NULL);
 }
+
+void
+crux_draw_style_class_init (GtkStyleClass *style_class)
+{
+  style_class->draw_hline = draw_hline;
+  style_class->draw_vline = draw_vline;
+  style_class->draw_shadow = draw_shadow;
+  style_class->draw_polygon = draw_polygon;
+  style_class->draw_arrow = draw_arrow;
+  style_class->draw_diamond = draw_diamond;
+  style_class->draw_string = draw_string;
+  style_class->draw_box = draw_box;
+  //style_class->draw_flat_box = draw_flat_box;
+  style_class->draw_check = draw_check;
+  style_class->draw_option = draw_option;
+  style_class->draw_tab = draw_tab;
+  style_class->draw_shadow_gap = draw_shadow_gap;
+  style_class->draw_box_gap = draw_box_gap;
+  style_class->draw_extension = draw_extension;
+  style_class->draw_focus = draw_focus;
+  style_class->draw_slider = draw_slider;
+  style_class->draw_handle = draw_handle;
+}
